@@ -23,11 +23,12 @@
 #include <QProcess>
 #include <QPushButton>
 #include <QScreen>
+#include <QStandardPaths>
 #include <QStringList>
 #include <QStyle>
 #include <QUrl>
 
-#ifndef KCONFIGWIDGETS_NO_KAUTH
+#if KCONFIGWIDGETS_WITH_KAUTH
 #include <KAuth/Action>
 #include <KAuth/ObjectDecorator>
 #endif
@@ -37,7 +38,6 @@
 #include <KMessageBox>
 #include <KPageWidgetModel>
 #include <KPluginInfo>
-#include <KPluginMetaData>
 
 bool KCMultiDialogPrivate::resolveChanges(KCModuleProxy *currentProxy)
 {
@@ -138,7 +138,7 @@ void KCMultiDialogPrivate::_k_clientChanged()
         QPushButton *applyButton = q->buttonBox()->button(QDialogButtonBox::Apply);
         if (applyButton) {
             q->disconnect(applyButton, &QAbstractButton::clicked, q, &KCMultiDialog::slotApplyClicked);
-#ifndef KCONFIGWIDGETS_NO_KAUTH
+#if KCONFIGWIDGETS_WITH_KAUTH
             delete applyButton->findChild<KAuth::ObjectDecorator *>();
 #endif
         }
@@ -146,12 +146,12 @@ void KCMultiDialogPrivate::_k_clientChanged()
         QPushButton *okButton = q->buttonBox()->button(QDialogButtonBox::Ok);
         if (okButton) {
             q->disconnect(okButton, &QAbstractButton::clicked, q, &KCMultiDialog::slotOkClicked);
-#ifndef KCONFIGWIDGETS_NO_KAUTH
+#if KCONFIGWIDGETS_WITH_KAUTH
             delete okButton->findChild<KAuth::ObjectDecorator *>();
 #endif
         }
 
-#ifndef KCONFIGWIDGETS_NO_KAUTH
+#if KCONFIGWIDGETS_WITH_KAUTH
         if (activeModule->realModule()->needsAuthorization()) {
             if (applyButton) {
                 KAuth::ObjectDecorator *decorator = new KAuth::ObjectDecorator(applyButton);
@@ -445,8 +445,13 @@ void KCMultiDialog::slotHelpClicked()
 
     const QUrl docUrl = QUrl(QStringLiteral("help:/")).resolved(QUrl(docPath)); // same code as in KHelpClient::invokeHelp
     const QString docUrlScheme = docUrl.scheme();
-    if (docUrlScheme == QLatin1String("man") || docUrlScheme == QLatin1String("info")) {
-        QProcess::startDetached(QStringLiteral("khelpcenter"), QStringList() << docUrl.toString());
+    const QString helpExec = QStandardPaths::findExecutable(QStringLiteral("khelpcenter"));
+    const bool foundExec = !helpExec.isEmpty();
+    if (!foundExec) {
+        qCDebug(KCMUTILS_LOG) << "Couldn't find khelpcenter executable in PATH.";
+    }
+    if (foundExec && (docUrlScheme == QLatin1String("man") || docUrlScheme == QLatin1String("info"))) {
+        QProcess::startDetached(helpExec, QStringList() << docUrl.toString());
     } else {
         QDesktopServices::openUrl(docUrl);
     }
@@ -674,7 +679,6 @@ void KCMultiDialog::clear()
 
     for (int i = 0; i < d->modules.count(); ++i) {
         removePage(d->modules[i].item);
-        delete d->modules[i].kcm;
     }
 
     d->modules.clear();
